# ml-botting-core
![](https://img.shields.io/pypi/v/ml-botting-core?style=for-the-badge) ![](https://img.shields.io/github/actions/workflow/status/darkmatter2222/ml-botting-core/python-publish.yml?style=for-the-badge) ![](https://img.shields.io/pypi/l/ml-botting-core?style=for-the-badge) ![](https://img.shields.io/pypi/pyversions/ml-botting-core?style=for-the-badge) 
ml-botting-core
